/**
 *  Copyright (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  Licensed under the GPL, Version 3.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.gnu.org/licenses/gpl.html
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * --------------------------------------------------------------------------
 *  版权 (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  本开源软件遵循 GPL 3.0 协议;
 *  如果您不遵循此协议，则不被允许使用此文件。
 *  你可以从下面的地址获取完整的协议文本
 *
 *       http://www.gnu.org/licenses/gpl.html
 */
package org.tinygroup.bumgt.cmd;

import org.apache.commons.vfs2.FileObject;
import org.apache.commons.vfs2.FileSystemException;
import org.apache.commons.vfs2.VFS;
import org.tinygroup.bu.BusinessUnitManager;
import org.tinygroup.bu.BusinessUnitManagerFactory;
import org.tinygroup.bu.util.BusinessUnitUtil;
import org.tinygroup.command.CommandGoalExecutor;
import org.tinygroup.command.CommandSystem;
import org.tinygroup.context.Context;
import org.tinygroup.logger.LogLevel;
import org.tinygroup.logger.Logger;
import org.tinygroup.logger.LoggerFactory;

//TODO 由陈佼去修改文件路径的问题
/**
 * 加载业务单元命令
 * 
 * @author luoguo
 * 
 */
public class BuJarLoadCommand implements CommandGoalExecutor {

	private static final int JAR_SPACE = 2;
	private String jarName;
	private static Logger logger = LoggerFactory
			.getLogger(BuJarLoadCommand.class);

	public String getJarName() {
		return jarName;
	}

	public void setJarName(String jarName) {
		this.jarName = jarName;
	}

	public void execute(CommandSystem commandHelper, Context context) {
		logger.logMessage(LogLevel.DEBUG, "开始执行指令：载入指定业务单元Jar包[{0}]", jarName);
		String path = context.get(BusinessUnitUtil.BU_BASE_DIR);
		if (path == null) {
			path = BusinessUnitUtil.getBuDir();
		}
		logger.logMessage(LogLevel.DEBUG, "业务单元根目录为[{0}]", path);
		FileObject[] files = null;
		try {
			FileObject jarFile = VFS.getManager().resolveFile(path);
			files = jarFile.getChildren();

			if (files.length == 0) {
				commandHelper.indentPrint("jar包不存在", 0);
				commandHelper.println();
				return;
			}
			for (FileObject file : files) {
				if (file.getName().getBaseName().equals(jarName)) {
					loadJar(commandHelper, context, file);
					return;
				}
			}
		} catch (FileSystemException e) {
			logger.logMessage(LogLevel.ERROR, "载入业务单元时出错,根目录[{0}]", path);
			logger.errorMessage(e.getMessage(), e);
		}
		logger.logMessage(LogLevel.DEBUG, "指令执行完毕：载入指定业务单元Jar包[{0}]", jarName);
	}

	private void loadJar(CommandSystem commandHelper, Context context,
			FileObject fileObject) {
		logger.logMessage(LogLevel.DEBUG, "开始载入业务单元[{0}]", fileObject.getName());
		BusinessUnitManager manager = BusinessUnitManagerFactory.getManager();
		commandHelper.indentPrint("载入Jar:" + fileObject.getName(), JAR_SPACE);
		commandHelper.println();
		manager.load(fileObject.getName().toString());
		logger.logMessage(LogLevel.DEBUG, "载入业务单元[{0}]结束", fileObject.getName());
	}

}
